import QtQuick 2.9
import QtQuick.Window 2.2
import QtQuick.Controls 2.2
import QtQuick.Layouts 1.3

Page {
    id: pageReleve
    width: parent.width
    padding: 10
    property int nbMesures: 5

    Connections {
        target: Releve
        onMoyenneUpdated: {
            labelMoyenne.text = "Moyenne : " + Releve.moyenne + " °C";
            labelMoyenne.color = "#0000FF"
            labelMoyenne.visible = true
        }
        onMesuresErreur: {
            labelMoyenne.text = "Aucune mesure pour ce relevé !";
            labelMoyenne.color = "#FF0000"
            labelMoyenne.visible = true
            resultats.visible = false
            indicateur.visible = false
        }
    }
    Column {
        id: colonnePage
        width: parent.width
        spacing: 15
        Row {
            Label {
                id: introduction
                wrapMode: Label.Wrap
                text: "Relevés de mesures de températures dans les serres"
            }
        }
        Row {
            ComboBox {
                id: choixReleve
                width: introduction.width
                model: Releve.listeReleves
                enabled: true;
            }
        }
        Row {
            spacing: 20
            Label {
                wrapMode: Label.Wrap
                text: "Nb dernières mesures :"
                anchors.verticalCenter: parent.verticalCenter
            }
            SpinBox {
                id: limiteNbMesures
                enabled: choixReleve.count > 0 ? true : false;
                value: nbMesures
                editable: true
            }
        }        
        Row {
            spacing: 20
            Button {
                id: annuleReleve
                enabled: choixReleve.count > 0 ? true : false;
                text: "Annuler"
                onClicked: {
                    resultats.visible = false
                    indicateur.visible = false
                    labelMoyenne.visible = false
                }
            }
            Button {
                id: voirReleve
                enabled: choixReleve.count > 0 ? true : false;
                text: "Voir le relevé"
                onClicked: {
                    if(Releve.lireReleve(choixReleve.currentText, limiteNbMesures.value))
                    {
                        Releve.lireMoyenneReleve(choixReleve.currentText, limiteNbMesures.value);
                        resultats.visible = true
                        indicateur.visible = true
                    }
                }
            }
            Button {
                id: purgerReleve
                enabled: choixReleve.count > 0 ? true : false;
                text: "Purger le relevé"
                onClicked: {
                    Releve.executerRequete("DELETE FROM releves WHERE releves.description = '" + choixReleve.currentText + "'");
                    resultats.visible = false
                    indicateur.visible = false
                    labelMoyenne.visible = false
                }
            }
        }
        Row {
            Label {
                id: labelMoyenne
                visible: false
                anchors.margins: 5
                wrapMode: Label.Wrap
                text: ""
            }
        }
        Row {
            ListView {
                id: resultats
                visible: false
                width: colonnePage.width
                height: Screen.desktopAvailableHeight * 0.45
                focus: true
                snapMode: ListView.SnapOneItem
                highlightRangeMode: ListView.StrictlyEnforceRange
                highlightMoveDuration: 250
                orientation: ListView.Horizontal
                boundsBehavior: Flickable.StopAtBounds

                model: ListModel {
                    ListElement {component: "Mesures.qml"}
                    ListElement {component: "Graphique.qml"}
                }

                delegate: Loader {
                    width: resultats.width
                    height: resultats.height
                    source: component
                    asynchronous: true
                }
            }
        }
        Row {
            anchors.horizontalCenter: parent.horizontalCenter
            PageIndicator {
                id: indicateur
                visible: false
                count: resultats.count
                currentIndex: resultats.currentIndex
            }
        }
    }
}
