import QtQuick 2.9
import QtQuick.Window 2.2
import QtQuick.Controls 2.2
import QtQuick.Layouts 1.3

ApplicationWindow {
    id: window
    title: qsTr("Mon MonApplicationBD MySQL")
    width: Screen.desktopAvailableWidth
    height: Screen.desktopAvailableHeight
    property bool erreur: Releve.erreurConnexion
    visible: true

    Component.onCompleted: {
        fenetreConnexion.open()
    }
    Dialog {
        id: fenetreConnexion
        x: (window.width - width) / 2
        y: window.height / 12
        focus: true
        modal: true
        title: "Base de données MySQL"
        standardButtons: Dialog.Ok | Dialog.Cancel
        ColumnLayout {
            spacing: 20
            anchors.fill: parent
            Label {
                elide: Label.ElideRight
                text: "Entrer les informations de connexion :"
                Layout.fillWidth: true
            }
            TextField {
                id: serveur
                focus: true
                placeholderText: "Serveur"
                inputMethodHints: Qt.ImhFormattedNumbersOnly
                Layout.fillWidth: true
            }
            TextField {
                id: utilisateur
                placeholderText: "Utilisateur"
                Layout.fillWidth: true
            }
            TextField {
                id: password
                placeholderText: "Mot de passe"
                echoMode: TextInput.Password
                Layout.fillWidth: true
            }
        }
        onAccepted: {
            if(Releve.connecterBD(serveur.text, utilisateur.text, password.text))
            {
                var component = Qt.createComponent("Releves.qml");
                if (component.status == Component.Ready)
                {
                     var page = component.createObject(vueReleve);
                     if (page == null)
                     {
                         console.log("Erreur création Releves.qml !");
                     }
                     else
                     {
                         connexion.enabled = false
                     }
                }
                else if (component.status == Component.Error)
                {
                     console.log("Erreur chargement Releves.qml :", component.errorString());
                }
            }
        }
    }
    onErreurChanged: {
        if (Releve.erreurConnexion)
        {
            messageErreur.text = qsTr("Problème d'ouverture de la base de données !")
            erreurDialog.open()
        }
    }
    header: ToolBar {
        RowLayout {
            spacing: 20
            anchors.fill: parent            
            Label {
                id: titre
                text: qsTr("Mon MonApplicationBD MySQL")
                font.pixelSize: 20
                elide: Label.ElideRight
                horizontalAlignment: Qt.AlignHCenter
                verticalAlignment: Qt.AlignVCenter
                Layout.fillWidth: true
            }
            ToolButton {
                id: toolButton2
                icon.name: "menu"
                onClicked: menu.open()
            }
        }
    }    
    Menu {
        id: menu
        x: parent.width - width
        transformOrigin: Menu.TopRight
        MenuItem {
            id: connexion
            text: "Connexion"
            onTriggered: {
                fenetreConnexion.open()
            }
        }
        MenuItem {
            id: about
            text: "À propos"
            onTriggered: {
                aPropos.open()
            }
        }
    }
    Dialog {
        id: aPropos
        modal: true
        focus: true
        title: "À propos"
        x: (window.width - width) / 2
        y: window.height / 6
        width: Math.min(window.width, window.height) / 3 * 2
        contentHeight: message.height
        Label {
            id: message
            width: aPropos.availableWidth
            text: "Exemple d'utilisation d'une base de données MySQL en Qt Quick Controls 2."
            wrapMode: Label.Wrap
            font.pixelSize: 12
        }
    }
    Dialog {
        id: erreurDialog
        x: (parent.width - width) / 2
        y: (parent.height - height) / 2
        standardButtons: Dialog.Close
        title: "Erreur"
        Label {
            id: messageErreur
            text: ""
        }
    }
    footer: Label {
            width: parent.width
            horizontalAlignment: Qt.AlignRight
            padding: 10
            text: qsTr("© http://tvaira.free.fr")
            font.pixelSize: 14
            font.italic: true
    }
    Item {
        id: vueReleve
        anchors.fill: parent
    }
}
