#include "releve.h"
#include "mesure.h"
#include <QDateTime>
#include <QDebug>

Releve::Releve(QObject *parent) : QObject(parent), erreurConnexion(false)
{    
}

Releve::~Releve()
{
}

bool Releve::connecterBD(QString serveur, QString utilisateur, QString password)
{
    //qDebug() << Q_FUNC_INFO << QSqlDatabase::drivers();
    db = QSqlDatabase::addDatabase("QMYSQL");

    qDebug() << Q_FUNC_INFO << serveur << utilisateur << password;
    db.setHostName(serveur);
    db.setUserName(utilisateur);
    db.setPassword(password);
    db.setDatabaseName(NOM_BD);

    if(db.open())
    {
        erreurConnexion = false;
    }
    else
    {
        erreurConnexion = true;
        qDebug() << Q_FUNC_INFO << QString::fromUtf8("Erreur : impossible de se connecter à la base de données !");
    }

    emit erreurChanged();

    return !erreurConnexion;
}

bool Releve::lireReleve(QString releve, int nb)
{
    if(erreurConnexion)
        return false;

    QVector<QStringList> relevesMesures;
    QString requete;

    if(nb > 0)
    {
        // les nb dernières mesures
        requete = "SELECT * FROM (SELECT mesures.horodatage, mesures.temperature FROM mesures INNER JOIN releves ON releves.idReleve = mesures.idReleve WHERE releves.description = '" + releve + "' ORDER BY mesures.horodatage DESC LIMIT " + QString::number(nb) + ") tmp ORDER BY horodatage ASC LIMIT " + QString::number(nb);
    }
    else
    {
        // toutes les mesures du relevé
        requete = "SELECT mesures.horodatage,mesures.temperature FROM mesures INNER JOIN releves ON releves.idReleve = mesures.idReleve WHERE releves.description = '" + releve + "' ORDER BY mesures.horodatage ASC";
    }

    qDeleteAll(mesures);
    mesures.clear();

    if(recuperer(requete, relevesMesures))
    {
        for(int i=0;i<relevesMesures.count();i++)
        {            
            Mesure *m = new Mesure(QDateTime::fromString(relevesMesures.at(i).at(0), "yyyy-MM-ddTHH:mm:ss"), relevesMesures.at(i).at(1).toDouble(), this);
            mesures.append(m);
        }

        if(mesures.count() > 0)
        {
            emit mesuresUpdated();
            return true;
        }
        else
        {
            emit mesuresErreur();
        }
    }
    else
    {
        emit mesuresErreur();
    }
    return false;
}

void Releve::lireMoyenneReleve(QString releve, int nb)
{
    if(erreurConnexion)
        return;

    QString requete;

    if(nb > 0)
    {
        // la moyenne des nb dernières mesures
        requete = "SELECT AVG(temperature) FROM (SELECT mesures.horodatage, mesures.temperature FROM mesures INNER JOIN releves ON releves.idReleve = mesures.idReleve WHERE releves.description = '" + releve + "' ORDER BY mesures.horodatage DESC LIMIT " + QString::number(nb) + ") tmp ORDER BY horodatage ASC LIMIT " + QString::number(nb);
    }
    else
    {
        // la moyenne de toutes les mesures du relevé
        requete = "SELECT AVG(mesures.temperature) FROM mesures INNER JOIN releves ON releves.idReleve = mesures.idReleve WHERE releves.description = '" + releve + "' ORDER BY mesures.horodatage ASC";
    }

    if(recuperer(requete, moyenne))
    {
        emit moyenneUpdated();
    }
}

/* pour : UPDATE, INSERT et DELETE */
bool Releve::executerRequete(QString requete)
{
    QSqlQuery r;

    if(db.isOpen())
    {
        bool retour = r.exec(requete);
        return retour;
    }
    return false;
}

QStringList Releve::getReleves()
{
    if(!erreurConnexion)
    {
        releves.clear();
        recuperer("SELECT description FROM releves ORDER BY releves.description ASC", releves);
    }

    return releves;
}

QVariant Releve::getMesures()
{
    return QVariant::fromValue(mesures);
}

QString Releve::getMoyenne()
{
    return moyenne;
}

bool Releve::recuperer(QString requete, QStringList &donnees)
{
    QSqlQuery r;
    bool retour;

    if(db.isOpen())
    {
        retour = r.exec(requete);
        if(retour)
        {
            // pour chaque enregistrement
            while ( r.next() )
            {
                // on stocke l'enregistrement dans le QStringList
                donnees << r.value(0).toString();
            }
            return true;
        }
        else
        {
            qDebug() << Q_FUNC_INFO << QString::fromUtf8("Erreur : %1 pour la requête %2").arg(r.lastError().text()).arg(requete);
            return false;
        }
    }
    else
        return false;
}

bool Releve::recuperer(QString requete, QVector<QStringList> &donnees)
{
    QSqlQuery r;
    bool retour;
    QStringList data;

    if(db.isOpen())
    {
        retour = r.exec(requete);
        if(retour)
        {
            // pour chaque enregistrement
            while ( r.next() )
            {
                // on récupère sous forme de QString la valeur de tous les champs sélectionnés
                // et on les stocke dans une liste de QString
                for(int i=0;i<r.record().count();i++)
                    data << r.value(i).toString();

                // on stocke l'enregistrement dans le QVector
                donnees.push_back(data);

                // on efface la liste de QString pour le prochain enregistrement
                data.clear();
            }
            return true;
        }
        else
        {
            return false;
        }
    }
    else
        return false;
}

bool Releve::recuperer(QString requete, QString &donnee)
{
    QSqlQuery r;
    bool retour;

    if(db.isOpen())
    {
        retour = r.exec(requete);
        if(retour)
        {
            // on se positionne sur l'enregistrement
            r.first();

            // on vérifie l'état de l'enregistrement retourné
            if(!r.isValid())
            {
                return false;
            }

            // on récupère sous forme de QString la valeur du champ
            if(r.isNull(0))
            {
                return false;
            }
            donnee = r.value(0).toString();
            return true;
        }
        else
        {
            return false;
        }
    }
    else
        return false;
}
