#ifndef RELEVE_H
#define RELEVE_H

#include <QObject>
#include <QString>
#include <QtSql/QtSql>
#include <QSqlDatabase>

#define NOM_BD QString("mabase")

class Releve : public QObject
{
    Q_OBJECT
    Q_PROPERTY(bool erreurConnexion MEMBER erreurConnexion NOTIFY erreurChanged)
    Q_PROPERTY(QStringList listeReleves READ getReleves NOTIFY listeRelevesChanged)
    Q_PROPERTY(QVariant mesures READ getMesures NOTIFY mesuresUpdated)
    Q_PROPERTY(QString moyenne READ getMoyenne NOTIFY moyenneUpdated)

public:
    explicit Releve(QObject *parent = nullptr);
    virtual ~Releve();

    Q_INVOKABLE bool connecterBD(QString serveur, QString utilisateur, QString password);
    Q_INVOKABLE bool lireReleve(QString releve, int nb=0);
    Q_INVOKABLE void lireMoyenneReleve(QString releve, int nb=0);
    Q_INVOKABLE bool executerRequete(QString requete);
    QStringList getReleves();
    QVariant getMesures();
    QString getMoyenne();

private:
    QSqlDatabase db;
    bool erreurConnexion;
    QStringList releves;
    QList<QObject*> mesures;
    QString moyenne;

    bool recuperer(QString requete, QStringList &donnees);
    bool recuperer(QString requete, QVector<QStringList> &donnees);
    bool recuperer(QString requete, QString &donnee);

signals:
    void erreurChanged();
    void listeRelevesChanged();
    void mesuresUpdated();
    void mesuresErreur();
    void moyenneUpdated();

public slots:
};

#endif // RELEVE_H
